@@ -102,9 +102,6 @@ class Url(object):
         self.get_context().set_response_headers(None)
         c = pycurl.Curl()
         
-        if self._verbose:
-            c.setopt(pycurl.VERBOSE, True)
-        
         protocol = self.get_context().get_protocol()
         self._logger.info("Protocol %s" % (protocol))
         bufResponseHeader = None
@@ -119,43 +116,7 @@ class Url(object):
                 self._logger.warn("Unknown Protocol %s !" % (protocol))
                 # No need to break here, it'll stop anyway
         
-        if self._insecure:
-            self._logger.info("Insecure SSL enabled")
-            c.setopt(pycurl.SSL_VERIFYHOST, 0)
-            c.setopt(pycurl.SSL_VERIFYPEER, 0)
-           
-        if self.get_context().get_client_certificate_file() is not None:
-            cert = self.get_context().get_client_certificate_file();
-            self._logger.info("Client Certificate File %s" % (cert))
-            try:
-                c.setopt(pycurl.SSLCERT, cert)
-            except TypeError, t:
-                self._logger.warn("Wrong setopt SSLCERT value %s" % (cert))
-                raise TypeError(t)
-            
-        if self.get_context().get_capath() is not None:
-            capath = self.get_context().get_capath();
-            self._logger.info("CA Path %s" % (capath))
-            try:
-                c.setopt(pycurl.CAPATH, capath)
-            except TypeError, t:
-                self._logger.warn("Wrong setopt CAPATH value %s" % (capath))
-                raise TypeError(t)
-            
-        if self.get_context().get_private_key_file() is not None:
-            privateKey = self.get_context().get_private_key_file()
-            self._logger.info("Private Key File %s" % (privateKey))
-            try:
-                c.setopt(pycurl.SSLKEY, privateKey)
-            except TypeError, t:
-                self._logger.warn("Wrong setopt SSLKEY value %s" % (privateKey))
-                raise TypeError(t)
-            
-        try:
-            c.setopt(pycurl.URL, self.get_context().get_url())
-        except TypeError, t:
-            self._logger.warn("Wrong setopt URL value %s" % (self.get_context().get_url()))
-            raise TypeError(t)
+        self._setCurlSetopts(c)
         
         bufResponse = cStringIO.StringIO()
         c.setopt(pycurl.WRITEFUNCTION, bufResponse.write)
@@ -182,7 +143,58 @@ class Url(object):
         bufResponse.close()
         self._logger.info(self.get_context().get_response())
         
-                
+    def _setCurlSetopts(self, c):
+        """
+        """
+        if self._verbose:
+            c.setopt(pycurl.VERBOSE, True)
+        
+        if self._insecure:
+            self._logger.info("Insecure SSL enabled")
+            c.setopt(pycurl.SSL_VERIFYHOST, 0)
+            c.setopt(pycurl.SSL_VERIFYPEER, 0)
+           
+        if self.get_context().get_client_certificate_file() is not None:
+            cert = self.get_context().get_client_certificate_file();
+            self._logger.info("Client Certificate File %s" % (cert))
+            try:
+                c.setopt(pycurl.SSLCERT, cert)
+            except TypeError, t:
+                self._logger.warn("Wrong setopt SSLCERT value %s" % (cert))
+                raise TypeError(t)
+
+        if self.get_context().get_server_connection_establishment_timeout() is not None:
+            self._logger.info("Server Connection Establishment Timeout %d" % (self.get_context().get_server_connection_establishment_timeout()))
+            try:
+                c.setopt(pycurl.CONNECTTIMEOUT, self.get_context().get_server_connection_establishment_timeout())
+            except TypeError, t:
+                self._logger.warn("Wrong setopt CONNECTTIMEOUT value %d" % (self.get_context().get_server_connection_establishment_timeout()))
+                raise TypeError(t)
+            
+        if self.get_context().get_capath() is not None:
+            capath = self.get_context().get_capath();
+            self._logger.info("CA Path %s" % (capath))
+            try:
+                c.setopt(pycurl.CAPATH, capath)
+            except TypeError, t:
+                self._logger.warn("Wrong setopt CAPATH value %s" % (capath))
+                raise TypeError(t)
+            
+        if self.get_context().get_private_key_file() is not None:
+            privateKey = self.get_context().get_private_key_file()
+            self._logger.info("Private Key File %s" % (privateKey))
+            try:
+                c.setopt(pycurl.SSLKEY, privateKey)
+            except TypeError, t:
+                self._logger.warn("Wrong setopt SSLKEY value %s" % (privateKey))
+                raise TypeError(t)
+            
+        try:
+            c.setopt(pycurl.URL, self.get_context().get_url())
+        except TypeError, t:
+            self._logger.warn("Wrong setopt URL value %s" % (self.get_context().get_url()))
+            raise TypeError(t)
+    
     def _prepareCommonHTTP(self, c):
         """
         """
